#
# spec file for package mftrace
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mftrace
Version:        1.2.20
Release:        4.1
Summary:        Scalable PostScript Fonts for MetaFont
License:        GPL-2.0-only
Group:          Productivity/Publishing/TeX/Utilities
URL:            https://lilypond.org/mftrace/
Source0:        https://lilypond.org/download/sources/mftrace/%{name}-%{version}.tar.gz
Source1:        gf2pbm.1
# build with gcc15
Patch0:         mftrace-gcc15.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  potrace
Requires:       bitmap_tracing
Requires:       fontforge
Requires:       t1utils
Requires:       texlive
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Mftrace is a small Python program that lets you trace a TeX bitmap font
into a PFA or PFB font (A PostScript Type1 Scalable Font) or TTF
(TrueType) font.

%prep
%autosetup -p1

%build
cp %{SOURCE1} .
autoreconf -fi
%configure \
	--with-pic
make CFLAGS="$RPM_OPT_FLAGS" %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
# remove files containing hardcoded rpath
rm -rf %{buildroot}%{_datadir}/mftrace/*.pyc

%files
%defattr(-, root, root)
%license COPYING
%doc ChangeLog README.txt
%{_bindir}/*
%{_datadir}/mftrace
%{_mandir}/man1/*

%changelog
* Tue May 13 2025 pgajdos@suse.com
- added patches
  build with gcc15
  + mftrace-gcc15.patch
* Fri May  6 2022 Marcus Meissner <meissner@suse.com>
- switch urls to https
* Thu Jun 17 2021 Steve Kowalik <steven.kowalik@suse.com>
- Remove unnecessary BuildRequires on python-devel.
* Tue Jan  5 2021 Wang Jun <jgwang@suse.com>
- Update to version 1.2.20
  * Fix p.add_option() issue
  * Fix parsing of italic correction
  * Fix FTP_DIR.
  * Migrate package to python3
  * Add manpage for gf2pbm
  * Quieten fontforge invocation
* Tue Oct 30 2018 Marketa Calabkova <mcalabkova@suse.com>
- Remove autotrace from build dependencies
  * Autotrace has many security bugs which will not be fixed
    (bsc#1040278), so it is better to drop it.
    Moreover it is not necessary here, so it should be
    removed from build dependencies.
* Mon Apr 27 2015 mpluskal@suse.com
- Update to 1.2.18
  * configure.in (PYTHON): bump version.
  * COPYING: GPL.
  * GNUmakefile.in (FILES): add GPL
- Cleanup spec file with spec-cleaner
- Use url for source
- Update dependencies
- Remove upstreamed/obsolete patches
  * mftrace-python-compile.patch
  * mftrace-rpm-opt-flags.patch
* Mon Dec  5 2011 sbrabec@suse.cz
- Upgrade to version 1.2.17:
  * minor fixes
  * potrace support improved
* Mon Dec  5 2011 cfarrell@suse.com
- license update: GPL-2.0
  Various files are GPL-2.0 (i.e. only). Use SPDX format
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sat Aug 16 2008 puzel@suse.cz
- update to bugfix release 1.2.15
  - fixes running in python>2.6 (misuse of as keyword)
* Fri May 23 2008 crrodriguez@suse.de
- use RPM_OPT_FLAGS
* Wed Jul 25 2007 sbrabec@suse.cz
- Updated to version 1.2.14:
  * Documentation fixes.
  * Minor fixes.
* Sun Apr 22 2007 ro@suse.de
- require texlive instead of tetex
* Fri Oct 20 2006 sbrabec@suse.cz
- Updated to version 1.2.5:
  * Code cleanup.
  * Documentation fixes.
  * Now probably requires python 2.x.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan  2 2006 sbrabec@suse.cz
- Updated to version 1.1.17.
* Tue Sep  6 2005 mmarek@suse.cz
- fixed problem with gcc4 and casting int* to char*, obsoleting
  mftrace-strict-aliasing.patch, closing lilypond bug #113762
* Mon Aug  1 2005 sbrabec@suse.cz
- Updated to version 1.1.12.
* Thu Jan  6 2005 sbrabec@suse.cz
- Updated to version 1.1.2.
- Require bitmap_tracing virtual instead of autotrace or potrace.
* Wed Aug 25 2004 sbrabec@suse.cz
- Updated to version 1.0.34.
- Fixed Requires (#44219).
* Thu Aug 19 2004 ro@suse.de
- pfaedit has been renamed to fontforge
* Fri Feb  6 2004 sbrabec@suse.cz
- Updated to version 1.0.27.
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Fri Aug  8 2003 sbrabec@suse.cz
- Updated to version 1.0.19.
* Mon Nov 25 2002 sbrabec@suse.cz
- Added new package.
